@@ -22,31 +22,59 @@ class EEDI3(_Antialiaser):
     nrad: int = 2
     mdis: int = 20
 
+    hp: bool = True
+    ucubic: bool = True
+    cost3: bool = True
+    vcheck: int = 2
+    vthresh0: float = 32.0
+    vthresh1: float = 64.0
+    vthresh2: float = 4.0
+
+    device: int = -1
     opencl: bool = dc_field(default=False, kw_only=True)
 
     mclip: vs.VideoNode | None = None
     sclip_aa: type[Antialiaser] | Antialiaser | None = Nnedi3(nsize=4, nns=4, qual=2, etype=1)
 
-    def get_aa_args(self, clip: vs.VideoNode, **kwargs: Any) -> dict[str, Any]:
-        return dict(alpha=self.alpha, beta=self.beta, gamma=self.gamma, nrad=self.nrad, mdis=self.mdis)
+    def __post_init__(self) -> None:
+        super().__post_init__()
 
-    def _interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
-        if not isinstance(self.sclip_aa, Antialiaser):
+        if self.sclip_aa and not isinstance(self.sclip_aa, Antialiaser):
             self.sclip_aa = self.sclip_aa()
 
-        if self.sclip_aa:
-            sclip_args = self.sclip_aa.get_aa_args(clip, **kwargs)
+    def get_aa_args(self, clip: vs.VideoNode, **kwargs: Any) -> dict[str, Any]:
+        args = dict(
+            alpha=self.alpha, beta=self.beta, gamma=self.gamma,
+            nrad=self.nrad, mdis=self.mdis,
+            hp=self.hp, ucubic=self.ucubic, cost3=self.cost3,
+            vcheck=self.vcheck,
+            vthresh0=self.vthresh0, vthresh1=self.vthresh1, vthresh2=self.vthresh2
+        ) | kwargs
+
+        if self.opencl:
+            args |= dict(device=self.device)
+
+        return args
+
+    def _interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
+        aa_kwargs = self.get_aa_args(clip, **kwargs)
+
+        if self.sclip_aa and ((('sclip' in kwargs) and not kwargs['sclip']) or 'sclip' not in kwargs):
+            sclip_args = self.sclip_aa.get_aa_args(clip)
+
             if double_y:
-                sclip_args |= self.sclip_aa.get_ss_args(clip, **kwargs)
+                sclip_args |= self.sclip_aa.get_ss_args(clip)
             else:
-                sclip_args |= self.sclip_aa.get_sr_args(clip, **kwargs)
+                sclip_args |= self.sclip_aa.get_sr_args(clip)
 
-            sclip = self.sclip_aa._interpolate(clip, double_y or not self.drop_fields)
-        else:
-            sclip = None
+            aa_kwargs.update(
+                sclip=self.sclip_aa._interpolate(clip, double_y or not self.drop_fields, **sclip_args)
+            )
 
-        interpolated = core.eedi3m.EEDI3(
-            clip, self.field, double_y or not self.drop_fields, sclip=sclip, **kwargs
+        function = core.eedi3m.EEDI3CL if self.opencl else core.eedi3m.EEDI3
+
+        interpolated = function(
+            clip, self.field, double_y or not self.drop_fields, **aa_kwargs
         )
 
         return self._shift_interpolated(clip, interpolated, double_y)
